@@ -10,6 +10,13 @@ class TestLockNullResource(unittest.TestCase):
 
         verifyClass(WriteLockInterface, LockNullResource)
 
+    def test_z3interfaces(self):
+        from webdav.interfaces import IWriteLock
+        from webdav.NullResource import LockNullResource
+        from zope.interface.verify import verifyClass
+
+        verifyClass(IWriteLock, LockNullResource)
+
 
 class TestNullResource(unittest.TestCase):
 
@@ -20,6 +27,13 @@ class TestNullResource(unittest.TestCase):
 
         verifyClass(WriteLockInterface, NullResource)
 
+    def test_z3interfaces(self):
+        from webdav.interfaces import IWriteLock
+        from webdav.NullResource import NullResource
+        from zope.interface.verify import verifyClass
+
+        verifyClass(IWriteLock, NullResource)
+
 
 def test_suite():
     return unittest.TestSuite((
